#ifndef MyNetLayer_h
#define MyNetLayer_h

#define MAX_PKT_LEN 1420

#define MAX_BUFFERED_PKTS 20

#include <arpa/inet.h>
#include <netinet/in.h>
#include <sys/socket.h>
#include <sys/types.h>


/**
  * MNL maintains an array of MNLBufs.  Depending on the value of mToSendFlag,
  * an MNLBuf represents packet that MNL needs to send out or it may represent
  * an empty slot.
  */
typedef struct {
  
  /**
    * 0 -> This is an empty slot
    * 1 -> This is packet that needs to be sent out.
    */
  int mToSendFlag;
  
  /** The contents of the packet to be sent out */
  unsigned char mpPkt[MAX_PKT_LEN];

  /** The length of the packet to be sent out */
  int mPktLen;
 
  /** Where should this packet be sent.  All internal fields in network byte order.
    */
  struct sockaddr_in mToAddr;

  /** The length of mToAddrLen */
  socklen_t mToLen;

  /** The flags associated with the sendto call */
  int mFlags;
  
} MNLBuf;


int MNLInit(const char* ipCfgFile );
void MNLDeInit();

#endif //MyNetLayer_h
