#include "TimeFns.h"

/**
  * @return 0 if t1 == t2.
  * 1 if t1 > t2
  * -1 if t1 < t2
  */
int TimeCmp (struct timeval t1, struct timeval t2) {

  if (t1.tv_sec > t2.tv_sec) {
    return 1;
  } else if (t1.tv_sec < t2.tv_sec) {
    return -1;
  } else {
    if (t1.tv_usec > t2.tv_usec) {
      return 1;
    } else if (t1.tv_usec < t2.tv_usec) {
      return -1;
    } else {
      return 0;
    }
  }
}

/**
  * @return t1 + t2
  */
struct timeval TimeAdd (struct timeval t1, struct timeval t2) {

  struct timeval lSum;
  lSum.tv_usec = t1.tv_usec + t2.tv_usec;
  lSum.tv_sec = t1.tv_sec + t2.tv_sec + lSum.tv_usec / 1000000;
  lSum.tv_usec = lSum.tv_usec % 1000000;
  return lSum;
}


/**
  * Returns t1 - t2.
  * If t1 < t2, returns 0.
  */
struct timeval TimeDiff (struct timeval t1, struct timeval t2) {
  struct timeval lDiff;
  lDiff.tv_sec = 0;
  lDiff.tv_usec = 0;

  if (TimeCmp(t1,t2) < 0) {
    return lDiff;
  }
  
  if (t1.tv_usec < t2.tv_usec) {
    t1.tv_usec += 1000000;
    t1.tv_sec -= 1;
  }

  lDiff.tv_usec = t1.tv_usec - t2.tv_usec;
  lDiff.tv_sec = t1.tv_sec - t2.tv_sec;

  return lDiff;
}
